@@ -4,6 +4,8 @@
 .onLoad <- function(libname, pkgname) {
   .package[["version"]] <- utils::packageVersion(pkgname)
 
+  import_future_functions()
+
   update_package_option("future.apply.debug", mode = "logical")
   debug <- getOption("future.apply.debug", FALSE)
 
@@ -11,7 +13,7 @@
     envs <- Sys.getenv()
     envs <- envs[grep("R_FUTURE_APPLY_", names(envs), fixed = TRUE)]
     envs <- sprintf("- %s=%s", names(envs), sQuote(envs))
-    mdebug(paste(c("Rnvironment variables specific to future.apply:", envs), collapse = "\n"))
+    mdebug(paste(c("R environment variables specific to future.apply:", envs), collapse = "\n"))
   }
 
   ## Set future options based on environment variables
